@@ -78,9 +78,13 @@ ITERATOR_BITSET_ALL_NOT_SET = 9
 ITERATOR_OVERLAPS = 10
 ITERATOR_NEIGHBOR = 11
 
+# Default value for connection timeout (seconds)
+CONNECTION_TIMEOUT = None
 # Default value for socket timeout (seconds)
 SOCKET_TIMEOUT = None
 # Default maximum number of attempts to reconnect
 RECONNECT_MAX_ATTEMPTS = 10
 # Default delay between attempts to reconnect (seconds)
 RECONNECT_DELAY = 0.1
+# Default cluster nodes list refresh interval (seconds)
+CLUSTER_DISCOVERY_DELAY = 60
